using UnityEngine;
using System.Collections;

public class GameController : MonoBehaviour {
	public enum GameState {
		                   PlayIntro, 
						   DisplayTitle, 
		                   GameOn
	                       };
	
	public GameState MyGameState;
	GameState LastGameState;
	
	IntroController MyIntroController;
	TitleController MyTitleController;
	GameRulesController MyGameRulesController;
	
	bool DoContinue;

	// Use this for initialization
	void Awake () {
		Screen.showCursor = false;	

		MyIntroController = FindObjectOfType(typeof(IntroController)) as IntroController;
		MyTitleController = FindObjectOfType(typeof(TitleController)) as TitleController;
		MyGameRulesController = FindObjectOfType(typeof(GameRulesController)) as GameRulesController;

		MyGameState = GameState.PlayIntro;	
	}
	
	// Update is called once per frame
	void Update () {

		// play the intro
		if (MyGameState == GameState.PlayIntro){
			if (!MyIntroController.IsActive){
				MyIntroController.StartIntro();
			}
	        
			if (MyIntroController.HasFinished){
				MyIntroController.StopIntro();
				
				LastGameState = GameState.PlayIntro;	
				MyGameState = GameState.DisplayTitle;					
			}
			
			QuitApplicationOnEscape ();
		}	
		
		// Display title screen
		if (MyGameState == GameState.DisplayTitle){
			if (!MyTitleController.IsActive){
				MyTitleController.StartTitle();
				DoContinue = false;
			}
			
			CheckForContinue();
			
			if (DoContinue){
				CheckForStartGame();
			}
			
			QuitApplicationOnEscape ();
			
		}	
		
		// the game is on
		if (   MyGameState == GameState.GameOn){
			if (   !MyGameRulesController.IsActive
				&& !MyGameRulesController.HasFinished ){
				MyGameRulesController.StartGameRules();
			}
	        
			ToTitleOnEscape ();
			
			// escape was pressed, go to title
			if (MyGameState == GameState.DisplayTitle){
				LastGameState = GameState.GameOn;	
				MyGameRulesController.StopGameRules();
			}
	
			// game has stopped, go to title
			if (MyGameRulesController.HasFinished){
				MyGameRulesController.ResetGameRules();
				LastGameState = GameState.GameOn;	
				MyGameState = GameState.DisplayTitle;
			}
		}	

	}
	
	void CheckForContinue(){
		// check that fire-key was released
		if (LastGameState == GameState.GameOn){
			if(!Input.GetButton("Fire1")){
				DoContinue = true;
			}
		}
		else {
			DoContinue = true;
		}
		
	}
	
	void CheckForStartGame(){
	   	if(Input.GetButton("Fire1")) {
			MyTitleController.StopTitle();
					
			LastGameState = GameState.DisplayTitle;	
			MyGameState = GameState.GameOn;					
		}
	}

	
	void QuitApplicationOnEscape (){		
		if (Input.GetKeyDown(KeyCode.Escape ) ){
			 Application.Quit();
		}
		
	}
	
	void ToTitleOnEscape (){		
		if (Input.GetKeyDown(KeyCode.Escape ) ){
			MyGameState = GameState.DisplayTitle;					
		}
		
	}
}
