using UnityEngine;
using System.Collections;

public class FlyingController : MonoBehaviour {
	Vector3 directionVector;
	float   directionLength;
	
	const float directionXDamping = 0.6f;
	const float directionYDamping = 0.6f;
	const float directionZDamping = 0.6f;
	
	FlyingPerformer PlayerPerformer;
	
	// Use this for initialization
	void Awake () {
		PlayerPerformer = FindObjectOfType(typeof(FlyingPerformer)) as FlyingPerformer;
	}
	
	// Update is called once per frame
	void FixedUpdate () {
		// Get the input vector from keyboard or analog stick
		directionVector.x = Input.GetAxis("Horizontal"); 
		directionVector.y = 0; 
		directionVector.z = Input.GetAxis("Vertical");
	
		if (directionVector != Vector3.zero) {
			// Get the length of the directon vector and then normalize it
			// Dividing by the length is cheaper than normalizing when we already have the length anyway
			directionLength = directionVector.magnitude;
			directionVector = directionVector / directionLength;
		
			// Make sure the length is no bigger than 1
			directionLength = Mathf.Min(1, directionLength);
		
			// Make the input vector more sensitive towards the extremes and less sensitive in the middle
			// This makes it easier to control slow speeds when using analog sticks
			directionLength = directionLength * directionLength;
		
			// Multiply the normalized direction vector by the modified length
			directionVector = directionVector * directionLength;
			
	
			directionVector.x = directionVector.x * directionXDamping;
			directionVector.y = directionVector.y * directionYDamping;
			directionVector.z = directionVector.z * directionZDamping;
			
			PlayerPerformer.MovePlayer(directionVector);			
		}
			
	}
	
	// Update is called once per frame
	void Update () {
	   	if(Input.GetButton("Fire1")) {
			PlayerPerformer.ShootGun();
		}

	}

}
